#
# spec file for package xfce4-terminal
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Guido Berhoerster.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           xfce4-terminal
Version:        0.6.3
Release:        4.16
Summary:        Terminal Emulator for the Xfce Desktop Environment
License:        GPL-2.0+
Group:          System/X11/Terminals
Url:            http://docs.xfce.org/apps/terminal/start
Source0:        http://archive.xfce.org/src/apps/xfce4-terminal/0.6/%{name}-%{version}.tar.bz2
BuildRequires:  fdupes
BuildRequires:  intltool
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(exo-1)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libxfce4ui-1)
BuildRequires:  pkgconfig(vte)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Recommends:     %{name}-lang = %{version}
Provides:       Terminal = %{version}
Obsoletes:      Terminal < %{version}
Obsoletes:      Terminal-doc < %{version}

%description
xfce4-terminal is a lightweight and easy to use terminal emulator for the Xfce
desktop environment. Its major features include a simple configuration
interface, the ability to use multiple tabs with terminals within a single
window, the possibility to have a pseudo-transparent terminal background, and a
compact mode where both the menubar and the window decorations are hidden which
helps to save space on the desktop.

# expanded %%lang_package with Obsoletes/Provides added
%package lang
Summary:        Languages for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Provides:       %{name}-lang-all = %{version}
Supplements:    packageand(bundle-lang-other:%{name})
Provides:       Terminal-lang = %{version}
Obsoletes:      Terminal-lang < %{version}
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%prep
%setup -q

%build
%configure
make %{?_smp_mflags} V=1

%install
%make_install

%suse_update_desktop_file %{name}

# create a list of localized man directories, these need to be owned
(
    printf '%%%%defattr(-,root,root)\n'
    cd '%{buildroot}'
    for dir in ".%{_mandir}/"*; do
        [ -d "${dir}" ] || continue
        case ${dir##*/} in
            man*)   continue ;;
            *)      lang="${dir##*/}"
                    printf "%%%%dir %%%%lang(%%s) %%s\n" "${lang}" "${dir#.}"
                    for subdir in "${dir}/"*; do
                        [ -d "${subdir}" ] || continue
                        printf "%%%%dir %%%%lang(%%s) %%s\n" "${lang}" \
                            "${subdir#.}"
                    done
                    ;;
        esac
    done
) >> %{name}.lang
%find_lang %{name} --with-man %{?no_lang_C}

%fdupes %{buildroot}/%{_mandir}

%clean
rm -rf %{buildroot}

%post
%desktop_database_post

%postun
%desktop_database_postun

%files
%defattr(-,root,root)
%doc README ChangeLog COPYING AUTHORS HACKING NEWS THANKS
%{_bindir}/xfce4-terminal
%dir %{_datadir}/xfce4
%{_datadir}/xfce4/terminal
%{_datadir}/applications/xfce4-terminal.desktop
%dir %{_datadir}/gnome-control-center
%{_datadir}/gnome-control-center/default-apps
%doc %{_mandir}/man1/xfce4-terminal.1*

%files lang -f %{name}.lang

%changelog
* Fri Dec 27 2013 gber@opensuse.org
- update to version 0.6.3
  - improve URL matching (bxo#7959, bxo#9800)
  - fix encoding menu creation (bxo#10395)
  - added light solarized colorscheme (bxo#10286)
  - fixed wrong foreground color in solarized dark (bxo#10285)
  - fix terminal session restore (bxo#9732)
  - translation updates
- drop obsolete
  xfce4-terminal-fix-up-the-encoding-menu-creation.patch
* Wed Oct 23 2013 lazy.kent@opensuse.org
-  Add xfce4-terminal-fix-up-the-encoding-menu-creation.patch: Fix
  up the encoding menu creation (bxo#10395).
* Sun May  5 2013 gber@opensuse.org
- update to version 0.6.2:
  - autotools updates
  - fix toolbars -> toolbar in docs
  - check display for the real display, not display.screen
  - display checking on drop-down windows
  - fix format warning
  - only call g_type_init on glib < 2.36
  - translation updates
* Mon Mar 11 2013 coolo@suse.com
- also obsolete Terminal-doc or you get an error on update
* Tue Jan  1 2013 gber@opensuse.org
- update to version 0.6.1:
  - add drop-down window support with --drop-down parameter, this
    allows xfce4-terminal to start 1 game-console like window
  - rename Go menu to Tabs
  - load default Alt+N accelerators on first startup
  - make single tab accelerator insensitive again
  - rename clear scrollbar to reset
  - fix crash when showing toolbar 2nd time
  - don't check for version and help in parameters parsing
  - remove Report Bug menu entry
  - hide search dialog on delete to avoid crash
  - set minimum tab label size to 10 chars
  - make right-click tab menu more functional
  - stop activity timeout when destroying a screen
  - rename $TERM to emulation and use new preference to avoid
    migration crashes
  - fix the tab re-use option when running from shortcut
  - allow underscore and + in email address
  - use new GPL license address
  - allow setting the geometry in the preferences
  - translation updates
* Fri Dec 28 2012 gber@opensuse.org
- provide/obsolete Terminal-lang correctly
* Fri Dec 28 2012 gber@opensuse.org
- Terminal was renamed to xfce4-terminal
